==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/member.dart <==
part of keyclic_sdk_api.api;

class Member {
  Member({
    this.roles,
    this.id,
    this.createdAt,
    this.type,
    this.links,
    this.embedded,
  });

  Member.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    roles = (json['roles'] as List)?.map((item) => item as String)?.toList();
    id = json['id'];
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    if (createdAt is DateTime && createdAt.isUtc == false) {
      createdAt = DateTime.parse('${createdAt.toIso8601String()}Z');
    }
    type = json['type'];
    links = MemberLinks.fromJson(json['_links']);
    embedded = MemberEmbedded.fromJson(json['_embedded']);
  }

  List<String> roles;

  String id;

  DateTime createdAt;

  String type;

  MemberLinks links;

  MemberEmbedded embedded;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is Member &&
        runtimeType == other.runtimeType &&
        id == other.id &&
        createdAt == other.createdAt;
  }

  @override
  int get hashCode => 0 ^ id.hashCode ^ createdAt.hashCode;

  Map<String, dynamic> toJson() {
    return {
      'roles': roles,
      'id': id,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'type': type,
      '_links': links,
      '_embedded': embedded,
    };
  }

  @override
  String toString() {
    return 'Member[roles=$roles, id=$id, createdAt=$createdAt, type=$type, links=$links, embedded=$embedded, ]';
  }

  static List<Member> listFromJson(List<dynamic> json) {
    return json == null
        ? List<Member>()
        : json.map((value) => Member.fromJson(value)).toList();
  }

  static Map<String, Member> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, Member>();
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = Member.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/member.dart <==
part of keyclic_sdk_api.api;

class Member {
  Member({
    this.embedded,
    this.links,
    this.createdAt,
    this.id,
    this.roles,
    this.type,
    this.updatedAt,
  });

  Member.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    embedded = MemberEmbedded.fromJson(json['_embedded']);
    links = MemberLinks.fromJson(json['_links']);
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    if (createdAt is DateTime && createdAt.isUtc == false) {
      createdAt = DateTime.parse('${createdAt.toIso8601String()}Z');
    }
    id = json['id'];
    roles = (json['roles'] as List)?.map((item) => item as String)?.toList();
    type = json['type'];
    updatedAt =
        json['updatedAt'] == null ? null : DateTime.parse(json['updatedAt']);
    if (updatedAt is DateTime && updatedAt.isUtc == false) {
      updatedAt = DateTime.parse('${updatedAt.toIso8601String()}Z');
    }
  }

  MemberEmbedded embedded;

  MemberLinks links;

  DateTime createdAt;

  String id;

  List<String> roles;

  String type;

  DateTime updatedAt;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is Member &&
        runtimeType == other.runtimeType &&
        embedded == other.embedded &&
        links == other.links &&
        createdAt == other.createdAt &&
        id == other.id &&
        DeepCollectionEquality.unordered().equals(roles, other.roles) &&
        type == other.type &&
        updatedAt == other.updatedAt;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^
      embedded.hashCode ^
      links.hashCode ^
      createdAt.hashCode ^
      id.hashCode ^
      roles.map((dynamic element) => element.hashCode).fold(0,
          (dynamic value, dynamic cursor) => value.hashCode ^ cursor.hashCode) ^
      type.hashCode ^
      updatedAt.hashCode;

  static List<Member> listFromJson(List<dynamic> json) {
    return json == null
        ? <Member>[]
        : json.map((value) => Member.fromJson(value)).toList();
  }

  static Map<String, Member> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, Member>();
    if (json != null && json.isNotEmpty) {
      json.forEach(
          (String key, dynamic value) => map[key] = Member.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      '_embedded': embedded,
      '_links': links,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'id': id,
      'roles': roles,
      'type': type,
      'updatedAt': updatedAt == null ? '' : updatedAt.toUtc().toIso8601String(),
    };
  }

  @override
  String toString() {
    return 'Member[embedded=$embedded, links=$links, createdAt=$createdAt, id=$id, roles=$roles, type=$type, updatedAt=$updatedAt, ]';
  }
}
